<?php
/*
Plugin Name: WordPress Wiki That Doesn't Suck (WPWTDS)
Description: A WordPress Wiki that works.
Version: 0.7
Author: Arcane Palette Creative Design
Author URI: http://arcanepalette.com/
License: gpl3
*/

/* here are some constants */
if ( ! defined( 'WP_CONTENT_URL' ) )
      define( 'WP_CONTENT_URL', get_option( 'siteurl' ) . '/wp-content' );
if ( ! defined( 'WP_CONTENT_DIR' ) )
      define( 'WP_CONTENT_DIR', ABSPATH . 'wp-content' );
if ( ! defined( 'WP_PLUGIN_URL' ) )
      define( 'WP_PLUGIN_URL', WP_CONTENT_URL. '/plugins' );
if ( ! defined( 'WP_PLUGIN_DIR' ) )
      define( 'WP_PLUGIN_DIR', WP_CONTENT_DIR . '/plugins' );

define('WPWTDS_PATH',WP_PLUGIN_URL.'/'.str_replace(basename( __FILE__),"",plugin_basename(__FILE__)));

/* this adds an admin menu */

/* saving this for when I have time and/or figure out how to make the form actually save the setting

add_action('admin_menu', 'wpwtds_menu');

function wpwtds_menu() {

  add_submenu_page( 'edit.php?post_type=wpwtds_article', __('WordPress Wiki Options That Don\'t Suck'), __('Options'), 'manage_options', 'wpwtds_options', wpwtds_options);
  
}


function wpwtds_options() {

  if (!current_user_can('manage_options'))  {
    wp_die( __('You do not have sufficient permissions to access this page.') );
  }

  echo '<div class="wrap">';
  echo '<h2>WordPress Wiki Options That Don\'t Suck</h2>';
  echo '<form method="post">';
  echo '<table class="form-table">';
  echo '<tbody>';
  echo '<tr valign="top">';
  echo '<th scope="row">';
  echo '<label for="slugname">Your Wiki\'s Slug</label>';
  echo '</th>';
  echo '<td>';
  echo '<input name="slug" type="text" id="wpwtdsslug" value="wiki" class="regular-text"><span class="description">You can change the default slug for your wiki pages.  Default is "wiki".</span>';
  echo '</td>';
  echo '</tr>';
  echo '</tbody>';
  echo '</table>';
  echo '<p class="submit">';
  echo '<input type="submit" name="Submit" class="button-primary" value="Save Changes">';
  echo '</p>';
  echo '</form>';
  echo '</div>';
}
*/

/**
 *
 * WPWTDS Post Type
 *
 * @package wordpress-wiki-that-doesnt-suck
 * @since 0.1
 *
 * creates a custom post type with a bunch of defined parameters 
 *
 */
function wpwtds_create_post_type() {
  register_post_type( 'wpwtds_article',
    array(
      'labels' => array(
		'name' => __( 'Wiki != suck' ),
		'singular_name' => __( 'Article' ),
		'add_new' => __( 'Post New Wiki' ),
		'add_new_item' => __( 'Add New Article' ),
		'edit' => __( 'Edit' ),
		'edit_item' => __( 'Edit Wiki' ),
		'new_item' => __( 'New Wiki' ),
		'view' => __( 'View Wiki' ),
		'view_item' => __( 'View Wiki' ),
		'search_items' => __( 'Search Articles' ),
		'not_found' => __( 'No articles found' ),
		'not_found_in_trash' => __( 'No articles found in Trash' ),
		'parent' => __( 'Parent Wiki' ),
      ),
      'public' => true,
	  'rewrite' => array('slug' => 'wiki','with_front' => 'false'),
	  'supports' => array('title','editor','revisions','author')
    )
  );
}
add_action( 'init', 'wpwtds_create_post_type' );

/**
 * WordPress Wiki That Doesn't Suck Taxonomy
 *
 * @package wordpress-wiki-that-doesnt-suck
 * @since 0.6.2
 * 
 * Adds a taxonomy to allow the ability to split wiki articles up into 'sections'
 */
function wpwtds_taxonomy() {
	register_taxonomy( 'wiki_section', 'wpwtds_article',
		array(
			 'hierarchical' => true, 
			 'labels' => array( 'name' => 'Sections', 'singular_name' => 'Section', 'add_new_item' => 'Add New Section' ),
			 'query_var' => 'wiki_section', 
			 'rewrite' => array( 'slug' => 'section' ) 
		)
	);
}
add_action( 'init', 'wpwtds_taxonomy' );

/**
 * WordPress Wiki That Doesn't Suck HTML meta box
 *
 * @package wordpress-wiki-that-doesnt-suck
 * @since 0.7
 *
 * This adds the call to the WPWTDS HTML area in the next section
 */
function wpwtds_htmlarea_meta() {
	add_meta_box('wpwtds-html','Custom HTML','wpwtds_htmlarea','wpwtds_article','normal','low'); 
}
add_action('admin_menu','wpwtds_htmlarea_meta');

/**
 *
 * WPWTDS HTML area
 * 
 * @package wordpress-wiki-that-doesnt-suck
 * @since 0.7
 *
 * This adds a meta box with an HTML textarea input.  This can then be placed wherever you want with get_post_meta
 * but the theory here is that you could do an "in this section" sort of block at the start of the document that includes 
 * anchor links to headings within the document.
 */ 
function wpwtds_htmlarea() {
    global $post;

	echo '<input type="hidden" name="wpwtds_noncename" id="wpwtds_noncename" value="' .
	wp_create_nonce( plugin_basename(__FILE__) ) . '" />';
	
	echo '<p><label for="wpwtds_html">Custom HTML</label><br />';
	echo '<textarea style="width: 90%;" rows="5" name="wpwtds_html">'.htmlspecialchars(get_post_meta($post->ID, 'wpwtds_html', true)).'</textarea><br />';
	echo 'You can add any custom HTML you like in this area and output it however you want using <tt>get_post_meta</tt>. The inteded use for this is to create an "In this section" area
	where you can have an unordered list with anchor links to sections within your single wiki pages.';
}

/**
 *
 * WPWTDS Save Article
 * 
 * @package wordpress-wiki-that-doesnt-suck
 * @since 0.7
 *
 * Saves the meta data when the article is saved
 *
 */
function wpwtds_save_article($post_id, $post) {
   	if ( !wp_verify_nonce( $_POST['wpwtds_noncename'], plugin_basename(__FILE__) )) {
	return $post->ID;
	}

	/* confirm user is allowed to save page/post */
	if ( 'page' == $_POST['post_type'] ) {
		if ( !current_user_can( 'edit_page', $post->ID ))
		return $post->ID;
	} else {
		if ( !current_user_can( 'edit_post', $post->ID ))
		return $post->ID;
	}

	/* ready our data for storage */
	foreach ($_POST as $key => $value) {
        $mydata[$key] = $value;
    }

	/* Add values of $mydata as custom fields */
	foreach ($mydata as $key => $value) {
		if( $post->post_type == 'revision' ) return;
		$value = implode(',', (array)$value);
		if(get_post_meta($post->ID, $key, FALSE)) {
			update_post_meta($post->ID, $key, $value);
		} else {
			add_post_meta($post->ID, $key, $value);
		}
		if(!$value) delete_post_meta($post->ID, $key);
	}
}

add_action('save_post', 'wpwtds_save_article', 1, 2); 

/**
 *
 * WordPress Wiki That Doesn't Suck article columns
 *
 * @package wordpress-wiki-that-doesnt-suck
 * @since 0.6.2
 *
 * Customizes the columns that appear on the Wiki != suck page
 */
function wpwtds_edit_article_columns( $columns ) {
	
	$columns = array(
		'cb' => '<input type="checkbox" />',
		'title' => 'Article',
		//'wiki_section' => 'Section',
		'date' => 'Date Published'
	);
	return $columns;
	
}
add_filter( 'manage_edit-wpwtds_article_columns', 'wpwtds_edit_article_columns');

// this adds the content from the custom 'section' column
/*
add_action( 'manage_wpwtds_article_custom_column', 'wpwtds_manage_custom_column', 10, 1 );
function wpwtds_manage_custom_column( $column, $post_id ) {
	global $post;
	
	// using a switch for really bad reasons
	switch( $column ) {

		case 'wiki_section' : 
			// get the taxonomy
			$terms = get_the_terms( $post_id, 'wiki_section' );
			
			// if something was found... 
			if ( !empty( $terms ) ) {
				$out = array();
				// loop through each term and link to the 'edit posts' screen for each one 
				foreach ( $terms as $term ) {
					$out[] = sprintf( '<a href="%s">%s</a>',
					esc_url( add_query_arg( array( 'post_type' => 'wpwtds_article', 'wiki_section' => $term->slug ), 'edit.php' ) ),
								esc_html( sanitize_term_field( 'name', $term->name, $term->term_id, 'wiki_section', 'display' ) )
							);
				}

						// Join the terms, separating them with a comma. 
						echo join( ', ', $out );
			}
			
					// If no terms were found, output a default message.
			else {
				_e( 'No Sections' );
			}
		break;
		default : break;
	}
} */

/**
 *
 * WPWTDS Menu Icon
 *
 * @package wordpress-wiki-that-doesnt-suck
 * @since 0.5
 *
 * Adds a custom menu icon for the wpwtds_article post type
 *
 */
function wpwtds_icon() {
    _e('
    <style type="text/css" media="screen">
        #menu-posts-wpwtds_article .wp-menu-image {
            background: url('.WPWTDS_PATH.'/images/wiki.png) no-repeat bottom !important;
			opacity: 0.7;
			-moz-opacity: 0.7;
			-webkit-opacity: 0.7;
			filter:alpha(opacity=70)
        }
	#menu-posts-wpwtds_article:hover .wp-menu-image, #menu-posts-wpwtds_article.wp-has-current-submenu .wp-menu-image {
			opacity: 1.0;
			-moz-opacity: 1.0;
			-webkit-opacity: 1.0;
			filter:alpha(opacity=100)
        }
    </style>');

 } 
add_action( 'admin_head', 'wpwtds_icon' );
 
 /**
  *
  * WPWTDS Header Icon
  *
  * @package wordpress-wiki-that-doesnt-suck
  * @since 0.6.2
  * 
  * Adds a custom header icon on the Wiki != suck page
  *
  */
 function wpwtds_header() {
        global $post_type;
	?>
	<style>
	<?php if (($_GET['post_type'] == 'wpwtds_article') || ($post_type == 'wpwtds_article')) : 
	_e('#icon-edit { background: url('.WPWTDS_PATH.'/images/wpwtds.png) no-repeat!important; } #icon-edit.icon32 { width: 50px!important; }');
	endif; ?>
        </style>
<?php } 
add_action('admin_head', 'wpwtds_header');
?>
